@@ -6,7 +6,7 @@ import logging
 
 import click
 
-from aicrowd.contexts import pass_config, ConfigContext
+from aicrowd.contexts import ConfigContext, pass_config
 from aicrowd.utils.utils import exception_handler
 
 
@@ -25,9 +25,10 @@ def login_command(config_context: ConfigContext, api_key: str):
 
     log = logging.getLogger()
 
+    gitlab_details = {}
     if api_key is None:
         log.info("API Key not provided in parameters, prompting")
 
-        api_key = url_login()
+        api_key, gitlab_details = url_login()
 
-    aicrowd_login(api_key, config_context)
+    aicrowd_login(api_key, gitlab_details, config_context)
