@@ -9,8 +9,8 @@ from aicrowd.contexts import (
     pass_challenge,
     pass_config,
 )
-from aicrowd.utils.utils import exception_handler
 from aicrowd.utils import AliasedGroup, CommandWithExamples
+from aicrowd.utils.utils import exception_handler
 
 
 @click.group(name="submission", cls=AliasedGroup)
@@ -20,7 +20,11 @@ def submission_command():
     """
 
 
-@click.command(name="create", cls=CommandWithExamples)
+@click.command(
+    name="create",
+    cls=CommandWithExamples,
+    context_settings={"ignore_unknown_options": True, "allow_extra_args": True},
+)
 @click.option(
     "-c",
     "--challenge",
@@ -52,8 +56,10 @@ def submission_command():
 )
 @pass_challenge
 @pass_config
+@click.pass_context
 @exception_handler
 def create_subcommand(
+    click_ctx,
     config_ctx: ConfigContext,
     challenge_ctx: ChallengeContext,
     challenge: str,
@@ -79,6 +85,12 @@ def create_subcommand(
     """
     from aicrowd.submission import create_submission
 
+    extra_args = {}
+    for arg in click_ctx.args:
+        if "=" in arg:
+            key, val = arg.split("=", 1)[:2]
+            extra_args[key] = val
+
     print(
         create_submission(
             challenge,
@@ -89,6 +101,7 @@ def create_subcommand(
             config_ctx,
             challenge_ctx,
             no_verify,
+            **extra_args
         )
     )
 
