@@ -7,6 +7,10 @@ import os
 RAILS_HOST = os.getenv("RAILS_HOST", "www.aicrowd.com")
 RAILS_API_ENDPOINT = f"https://{RAILS_HOST}/api/v1"
 AICROWD_API_ENDPOINT = os.getenv("AICROWD_API_ENDPOINT", "https://api.aicrowd.com")
+AICROWD_GITLAB_HOST = os.getenv("AICROWD_GITLAB_HOST", "gitlab.aicrowd.com")
+
+GITLAB_HOST = os.getenv("GITLAB_HOST", "gitlab.aicrowd.com")
+GITLAB_API_ENDPOINT = f"https://{GITLAB_HOST}/api/v4"
 
 DATASETS_HOST = os.getenv("DATASETS_HOST", "datasets.aicrowd.com")
 
@@ -17,6 +21,7 @@ class LoginConstants:
     """
 
     CONFIG_KEY = "aicrowd_api_key"
+    GITLAB_DETAILS_CONFIG_KEY = "gitlab"
     URL_LOGIN_REQUEST_LIFETIME = 120
 
 
