@@ -5,11 +5,12 @@ This class describes the config for the CLI
 import logging
 import os
 from pathlib import Path
+from typing import Dict, Union
 
 import click
 import toml
 
-from aicrowd.errors import INVALID_FILE, CONFIG_NOT_SET
+from aicrowd.errors import CONFIG_NOT_SET, INVALID_FILE
 from aicrowd.exceptions import CLIException
 
 
@@ -21,7 +22,7 @@ class CLIConfig:
     def __init__(self):
         self.log: logging.Logger = logging.getLogger()
         self.config_path: str = None
-        self.__settings: dict = None
+        self._settings: Dict = None
 
     def load(self, config_path: str):
         """
@@ -48,13 +49,13 @@ class CLIConfig:
 
         try:
             with open(self.config_path, "r") as config:
-                self.__settings = toml.load(config)
+                self._settings = toml.load(config)
                 self.log.info("Config loaded")
         except toml.TomlDecodeError:
             self.log.error(
                 "Malformed config file: %s. Will be overwritten", self.config_path
             )
-            self.__settings = {}
+            self._settings = {}
 
     def write(self):
         """
@@ -65,14 +66,16 @@ class CLIConfig:
         Path(basedir).mkdir(parents=True, exist_ok=True)
 
         with open(self.config_path, "w+") as config_file:
-            toml.dump(self.__settings, config_file)
+            toml.dump(self._settings, config_file)
             self.log.info(
                 "Successfully saved config to %s\n---\n%s\n---",
                 self.config_path,
-                self.__settings,
+                self._settings,
             )
 
-    def get(self, key: str, ensure_exists: bool = False, help_msg: str = "") -> str:
+    def get(
+        self, key: str, ensure_exists: bool = False, help_msg: str = ""
+    ) -> Union[str, Dict]:
         """
         Gets a key from config
 
@@ -86,10 +89,10 @@ class CLIConfig:
         Returns:
             the value for the key
         """
-        if self.__settings is None:
+        if self._settings is None:
             self.load(self.config_path)
 
-        value = self.__settings.get(key)
+        value = self._settings.get(key)
 
         if value is None and ensure_exists:
             self.log.warning("Queried config for %s but not found", key)
@@ -99,7 +102,7 @@ class CLIConfig:
 
         return value
 
-    def set(self, key: str, value: str):
+    def set(self, key: str, value: Union[str, Dict]):
         """
         Sets a key to value in config
 
@@ -107,7 +110,7 @@ class CLIConfig:
             key: config key
             value: config value
         """
-        if self.__settings is None:
+        if self._settings is None:
             self.load(self.config_path)
 
-        self.__settings[key] = value
+        self._settings[key] = value
