@@ -51,3 +51,9 @@ class LocalEvaluationError(NotebookException):
     """
     Exception for local evaluation failure
     """
+
+
+class NotebookFetchException(NotebookException):
+    """
+    Exception for failure while getting latest notebook content from frontend
+    """
