@@ -3,10 +3,11 @@ The submission create subcommand
 """
 
 import logging
+from typing import Optional
 
 from aicrowd.constants import ChallengeConstants
 from aicrowd.contexts import ChallengeContext, ConfigContext
-from aicrowd.errors import INVALID_PARAMETER
+from aicrowd.errors import INVALID_CHALLENGE_REPO, INVALID_PARAMETER
 from aicrowd.submission.exceptions import (
     ChallengeNotFoundException,
     InvalidChallengeDirException,
@@ -26,10 +27,11 @@ def create_submission(
     file_path: str,
     description: str,
     print_links: bool = False,
-    submission_tag: str = None,
+    submission_tag: Optional[str] = None,
     config_ctx: ConfigContext = ConfigContext(),
     challenge_ctx: ChallengeContext = ChallengeContext(),
     no_verify: bool = False,
+    **extra_kwargs,
 ):
     """
     Creates a submission on AIcrowd
@@ -88,6 +90,11 @@ def create_submission(
     if file_path is None:
         if not no_verify:
             verify_git_submission(api_key, challenge_id)
+        if not challenge_ctx.challenge.repo:
+            raise InvalidChallengeDirException(
+                "Couldn't find a git repo at the challenge location",
+                exit_code=INVALID_CHALLENGE_REPO,
+            )
         return submit_git(
             challenge_ctx.challenge.repo, description, submission_tag, print_links
         )
@@ -97,4 +104,6 @@ def create_submission(
 
     # challenge_slug is not unbound
     # we'll reach here only if initial challenge_id isn't set and we call parse_cli_challenge
-    return submit_file(challenge_slug, file_path, description, api_key, print_links)
+    return submit_file(
+        challenge_slug, file_path, description, api_key, print_links, extra_kwargs
+    )
