@@ -8,7 +8,7 @@ import re
 import shutil
 from json.decoder import JSONDecodeError
 from pathlib import Path
-from typing import Tuple, Union
+from typing import Any, Dict, Optional, Tuple, Union
 
 import requests
 from git import Remote, Repo
@@ -222,7 +222,8 @@ def notify_rails_upload(
     submitted_url: str,
     api_key: str,
     description: str,
-    problem_slug: str = None,
+    problem_slug: Optional[str] = None,
+    payload_extra_args: dict = {},
 ) -> dict:
     """
     notify rails about the uploaded file on s3
@@ -238,6 +239,7 @@ def notify_rails_upload(
     """
     log = logging.getLogger()
 
+    payload: Dict[str, Any]
     if problem_slug is None:
         payload = {"challenge_id": challenge_slug}
     else:
@@ -245,11 +247,26 @@ def notify_rails_upload(
 
     payload.update(
         {
-            "description": description,
+            "submission": {"description": description},
             "submission_files": [{"submission_file_s3_key": submitted_url}],
         }
     )
 
+    # only allow these extra args in payload
+    # also, map keys to what rails expects
+    extra_args_mapper = {"track": "clef_run_type"}
+    for extra_arg in payload_extra_args:
+        if extra_arg in extra_args_mapper:
+            logging.debug(
+                "Adding extra payload arg %s=%s",
+                extra_args_mapper[extra_arg],
+                payload_extra_args[extra_arg],
+            )
+            payload["submission"][extra_args_mapper[extra_arg]] = payload_extra_args[
+                extra_arg
+            ]
+
+    logging.debug("Constructed payload %s", payload)
     r = create_rails_submission(api_key, payload)
 
     if not r.ok:
@@ -314,6 +331,7 @@ def submit_file(
     description: str,
     api_key: str,
     print_links: bool,
+    payload_extra_args: dict = {},
 ) -> dict:
     """
     Submits a file given it's path and challenge_slug with given description
@@ -361,7 +379,7 @@ def submit_file(
         )
 
     response = notify_rails_upload(
-        challenge_slug, s3_key, api_key, description, problem_slug
+        challenge_slug, s3_key, api_key, description, problem_slug, payload_extra_args
     )
     if not response.get("success"):
         log.error("Couldn't notify AIcrowd servers about uploaded submission")
@@ -451,7 +469,7 @@ def generate_submission_tag(repo: Repo, submission_description: str) -> str:
 def submit_git(
     repo: Repo,
     submission_message: str,
-    submission_tag: str = None,
+    submission_tag: Optional[str] = None,
     print_links: bool = False,
 ):
     """
